﻿using System;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace Post
{
    public class MinimapEditInteractiveOverlay : EditInteractiveOverlay
    {
        private Feature draggingFeature;
        private bool isDragging;

        public MinimapEditInteractiveOverlay(WpfMap targetMap)
            : base()
        {
            if (targetMap == null) { throw new ArgumentNullException(); }

            TargetMap = targetMap;
            CanReshape = false;
            CanResize = false;
            CanRotate = false;
        }

        public WpfMap TargetMap { get; set; }

        protected override void OnFeatureDragged(FeatureDraggedEditInteractiveOverlayEventArgs e)
        {
            base.OnFeatureDragged(e);
            draggingFeature = e.DraggedFeature;
            isDragging = true;
        }

        protected override void OnMapMouseUp(MapMouseUpInteractiveOverlayEventArgs e)
        {
            base.OnMapMouseUp(e);

            if (TargetMap != null && isDragging)
            {
                TargetMap.CurrentExtent = draggingFeature.GetBoundingBox();
                TargetMap.Refresh();
                isDragging = false;
            }
        }

        protected override void OnMapMouseWheel(MapMouseWheelInteractiveOverlayEventArgs e)
        {
            base.OnMapMouseWheel(e);

            if (TargetMap != null)
            {
                if (e.InteractionArguments.MouseWheelDelta > 0)
                {
                    TargetMap.ZoomIn();
                }
                else
                {
                    TargetMap.ZoomOut();
                }
            }
        }
    }
}
