﻿using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace Post
{
    public partial class Window1 : Window
    {
        private bool isMinimapLoaded;
        private MinimapEditInteractiveOverlay minimapInteractiveOverlay;

        public Window1()
        {
            InitializeComponent();
        }

        private void Map1_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapUnit = GeographyUnit.DecimalDegree;
            Map1.CurrentExtent = new RectangleShape(-130, 90, 130, -90);
            InitializeOverlays(Map1);

            Map1.Refresh();
        }

        private void Minimap_Loaded(object sender, RoutedEventArgs e)
        {
            Minimap.MapUnit = GeographyUnit.DecimalDegree;
            Minimap.MapTools.PanZoomBar.IsEnabled = false;
            Minimap.MapTools.Logo.IsEnabled = false;
            Minimap.ExtentOverlay.PanMode = MapPanMode.Disabled;
            Minimap.ExtentOverlay.MouseWheelMode = MapMouseWheelMode.Disabled;
            minimapInteractiveOverlay = new MinimapEditInteractiveOverlay(Map1);
            Minimap.InteractiveOverlays.Add(minimapInteractiveOverlay);
            InitializeOverlays(Minimap);

            isMinimapLoaded = true;
        }

        private void InitializeOverlays(WpfMap map)
        {
            WorldMapKitWmsWpfOverlay worldOverlay = new WorldMapKitWmsWpfOverlay();
            map.Overlays.Add("WMK", worldOverlay);

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"C:\TG-ChenHao\Development\WpfDesktopEdition\HowDoISamples\CSharp Samples\SampleData\Data\Countries02.shp");
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.FromArgb(100, GeoColor.SimpleColors.Green));
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay shapeOverlay = new LayerOverlay() { TransitionEffect = TransitionEffect.None };
            shapeOverlay.Layers.Add("WorldLayer", worldLayer);
            map.Overlays.Add("WorldOverlay", shapeOverlay);
        }

        private void Map1_CurrentExtentChanged(object sender, CurrentExtentChangedWpfMapEventArgs e)
        {
            if (isMinimapLoaded && minimapInteractiveOverlay != null)
            {
                minimapInteractiveOverlay.EditShapesLayer.InternalFeatures.Clear();
                minimapInteractiveOverlay.EditShapesLayer.InternalFeatures.Add(new Feature(Map1.CurrentExtent.CloneDeep()));
                minimapInteractiveOverlay.CalculateAllControlPoints();

                try
                {
                    Minimap.CurrentExtent = ExtentHelper.ZoomOut(Map1.CurrentExtent, 50);
                }
                catch
                {
                    Minimap.CurrentExtent = Map1.MaxExtent;
                }
                Minimap.Refresh();
            }
        }
    }
}
